@@ -59,6 +59,9 @@ def html(options):
     template_args
       dictionary of values to be passed as name-value pairs to the HTML builder
       default: {}
+    config_args
+      dictionary of values to be passed as name-value pairs to configuration
+      default: {}
     """
     run_sphinx(options, 'html')
     return
@@ -155,6 +158,12 @@ def run_sphinx(options, *option_sets):
     template_args
       dictionary of values to be passed as name-value pairs to the HTML builder
       default: {}
+    config_args
+      dictionary of values to be passed as name-value pairs to configuration
+      default: {}
+    warnerror
+      Flag indicating that Sphinx warnings should be treated as errors.
+      Defaults to False.
     """
     if 'sphinx' not in option_sets:
         option_sets += ('sphinx',)
@@ -168,6 +177,10 @@ def run_sphinx(options, *option_sets):
         '-A%s=%s' % (name, value)
         for (name, value) in getattr(options, 'template_args', {}).items()
     ]
+    config_args = [
+        '-D%s=%s' % (name, value)
+        for (name, value) in getattr(options, 'config_args', {}).items()
+    ]
     sphinxopts = [
         '',
         '-b', options.get('builder', 'html'),
@@ -179,8 +192,11 @@ def run_sphinx(options, *option_sets):
         sphinxopts.append('-a')
     if options.get('freshenv', False):
         sphinxopts.append('-E')
+    if options.get('warnerror', False):
+        sphinxopts.append('-W')
 
     sphinxopts.extend(template_args)
+    sphinxopts.extend(config_args)
     sphinxopts.extend([paths.srcdir, paths.outdir])
     rc = dry("sphinx-build %s" % (" ".join(sphinxopts),),
              _wrap_sphinx, sphinxopts)
@@ -259,7 +275,7 @@ def adjust_line_widths(lines, break_lines_at, line_break_mode):
             )
 
         elif line_break_mode == 'fill':
-            prefix = l[:len(l)-len(l.lstrip())]
+            prefix = l[:len(l) - len(l.lstrip())]
             broken_lines.extend(
                 textwrap.fill(l, width=break_lines_at,
                               subsequent_indent=prefix).splitlines()
@@ -290,6 +306,7 @@ def run_script(input_file, script_name,
                break_lines_at=0,
                line_break_mode='break',
                adjust_python_for_version=True,
+               line_cleanups=[],
                ):
     """Run a script in the context of the input_file's directory,
     return the text output formatted to be included as an rst
@@ -341,6 +358,14 @@ def run_script(input_file, script_name,
       Boolean controlling whether the default `python`
       interpreter setting is changed to `python3` when
       running under python 3.
+
+    line_cleanups=[]
+      Process each output line through the cleanups and replace the
+      input line with the output values. Each cleanup should be a
+      callable that accepts the name of the original input file and
+      the line of output produced and returns a replacement string, or
+      the original input string if no changes are to be made.
+
     """
     rundir = path(input_file).dirname()
     if (adjust_python_for_version
@@ -361,6 +386,7 @@ def run_script(input_file, script_name,
         'cmd': cmd,
     }
     try:
+        print()
         output_text = sh(real_cmd, capture=True, ignore_error=ignore_error)
     except Exception as err:
         print('*' * 50)
@@ -379,7 +405,7 @@ def run_script(input_file, script_name,
 
     command_line = adjust_line_widths(
         ['\t$ %s' % cmd],
-        break_lines_at - 1 if break_lines_at else 73,
+        break_lines_at - 1 if break_lines_at else 64,
         'continue',
     )
 
@@ -388,6 +414,14 @@ def run_script(input_file, script_name,
     lines.append('')  # a blank line
     lines.extend(output_text.splitlines())  # the output
 
+    # Clean up the raw output lines.
+    clean_lines = []
+    for line in lines:
+        for cleanup in line_cleanups:
+            line = cleanup(input_file, line)
+        clean_lines.append(line)
+    lines = clean_lines
+
     # Deal with lines that might be too long
     if break_lines_at:
         lines = adjust_line_widths(lines, break_lines_at, line_break_mode)
@@ -424,9 +458,9 @@ def _runcog(options, files, uncog=False):
         c.options.defines['include'] = include
         c.options.defines['sh'] = _cogsh(c)
 
-    c.sBeginSpec = options.get('beginspec', '[[[cog')
-    c.sEndSpec = options.get('endspec', ']]]')
-    c.sEndOutput = options.get('endoutput', '[[[end]]]')
+    c.options.sBeginSpec = options.get('beginspec', '[[[cog')
+    c.options.sEndSpec = options.get('endspec', ']]]')
+    c.options.sEndOutput = options.get('endoutput', '[[[end]]]')
 
     basedir = options.get('basedir', None)
     if basedir is None:
@@ -465,8 +499,12 @@ def cog(options):
     files_to_cog = getattr(options, 'args', [])
     if files_to_cog and os.path.isdir(files_to_cog[0]):
         dir_to_scan = path(files_to_cog[0])
-        files_to_cog = dir_to_scan.walkfiles(
+        files_to_cog = list(dir_to_scan.walkfiles(
             options.get("pattern", "*.rst")
-        )
-    _runcog(options, files_to_cog)
+        ))
+    try:
+        _runcog(options, files_to_cog)
+    except Exception as err:
+        print('ERROR: %s' % err)
+        raise
     return
